@@ -12,5 +12,8 @@ settings = {
 	'reversed_timeline': False,
 	'reversed_mentions': False,
 	'reversed_stalk': False,
-	'WOEID': 1
+	'WOEID': 1,
+	'archive_path': '/path/',
+	'reversed_archive' : False,
+	'timezone': 'Europe/Paris'
 }
\ No newline at end of file
